<?php

namespace Ems\portalGestor\Service;

use Ems\portalGestor\Util\HcmServices;

class AdmissaoService {
    /** @var HcmServices */
    protected $hcmServices;

    public function __construct(
        HcmServices $hcmServices
    ) {
        $this->hcmServices = $hcmServices;
    }

    public function getVinculosNaoAprovados(
        int    $nrOrg,
        string $cdOperador,
               $nrEstrutura
    ): array {
        $route = 'getVinculosNaoAprovados';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'CDOPERADOR'    => $cdOperador,
                'NRESTRUTURAM'  => $nrEstrutura,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $admissoes = $result['dataset'][$route];

        return $admissoes;
    }

    public function setAdmissaoSimplificada(
        array $row
    ): bool {
        $route = 'setAdmissaoSimplificada';
        $nrOrg = (int) $row['NRORG'];

        $params = [
            'requestType' => 'Row',
            'row' => $row,
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $success = $result['dataset'][$route]['success'];

        return $success;
    }

    public function getTipoFormacaoParc(
        int    $nrOrg
    ): array {
        $route = 'getTipoFormacaoParc';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $tiposFormacao = $result['dataset'][$route];

        return $tiposFormacao;
    }

    public function getCursoAcademico(
        int    $nrOrg
    ): array {
        $route = 'getCursoAcademico';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $cursos = $result['dataset'][$route];

        return $cursos;
    }

    public function getInstituicaoEstrutura(
        int    $nrOrg
    ): array {
        $route = 'getInstituicaoEstrutura';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $instituicoes = $result['dataset'][$route];

        return $instituicoes;
    }

    public function getAreaFormacao(
        int    $nrOrg
    ): array {
        $route = 'getAreaFormacao';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $areas = $result['dataset'][$route];

        return $areas;
    }

    public function getBeneficio(
        int    $nrOrg
    ): array {
        $route = 'getBeneficio';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $beneficios = $result['dataset'][$route];

        return $beneficios;
    }
}