<?php
namespace EMS\portalGestor\Service;

use Doctrine\ORM\EntityManager;
use Ems\portalGestor\Util\HcmServices;

use EMS\portalGestor\Util\DateUtil;

class SolicitacaoService {
    /** @var EntityManager */
    protected $entityManager;

    /** @var HcmServices */
    protected $hcmServices;

    public function __construct(
        EntityManager $entityManager,
        HcmServices $hcmServices
    ) {
        $this->entityManager    = $entityManager;
        $this->hcmServices      = $hcmServices;
    }

    public function getSolicitacoesVinculosGestor(
        int $nrOrg,
        int $nrEstrutura
    ): array {
        $route = 'getSolicitacoesVinculosGestor';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRESTRUTURAM' => $nrEstrutura
            ]
        ];

        $result = $this->hcmServices->send(
            $route, $params, $nrOrg
        );

        $solicitacoes = $result['dataset']['getSolicitacoesVinculosGestor'];

        return $solicitacoes;
    }

    public function getItemSolicitacao($nrorg, $nrsolicitacao) {
        $getSolicitacaoRoute = 'getItemSolicitacao';

        $result = $this->hcmServices->send(
            $getSolicitacaoRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRSOLICITACAO'          => $nrsolicitacao,
                )
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getItemSolicitacao'];
    }
    
    public function getUltimoSalario($nrorg, $nrvinculom) {
        $getUltimoSalarioRoute = 'getUltimoSalario';

        $result = $this->hcmServices->send(
            $getUltimoSalarioRoute,
            array(
                'requestType' => 'Row',
                'row' => array(
                    'NRVINCULOM'          => $nrvinculom,
                )
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getUltimoSalario'];
    }
    
    public function getTiposolicitacao($nrorg) {
        $getTiposolicitacao = 'getTiposolicitacao';

        $result = $this->hcmServices->send(
            $getTiposolicitacao,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getTiposolicitacao'];
    }
    
    public function getTpAvisoPrevio($nrorg) {
        $getTpAvisoPrevio = 'getTpAvisoPrevio';

        $result = $this->hcmServices->send(
            $getTpAvisoPrevio,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getTpAvisoPrevio'];
    }
    
    public function getTpDemissao($nrorg) {
        $getTpDemissao = 'getTpDemissao';

        $result = $this->hcmServices->send(
            $getTpDemissao,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getTpDemissao'];
    }
    
    public function getMotivoResc($nrorg) {
        $getMotivoResc = 'getMotivoResc';

        $result = $this->hcmServices->send(
            $getMotivoResc,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getMotivoResc'];
    }
    
    public function getModalidadeSalarial($nrorg) {
        $getModalidadeSalarial = 'getModalidadeSalarial';

        $result = $this->hcmServices->send(
            $getModalidadeSalarial,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getModalidadeSalarial'];
    }
    
    public function getTipoAlteraSal($nrorg) {
        $getTipoAlteraSal = 'getTipoAlteraSal';

        $result = $this->hcmServices->send(
            $getTipoAlteraSal,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getTipoAlteraSal'];
    }

    public function getMotivoOcupa($nrorg) {
        $getMotivoOcupa = 'getMotivoOcupa';

        $result = $this->hcmServices->send(
            $getMotivoOcupa,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getMotivoOcupa'];
    }
    
    public function getOcupacao($nrorg) {
        $getOcupacao = 'getOcupacao';

        $result = $this->hcmServices->send(
            $getOcupacao,
            array(
                'requestType' => 'Row',
                'row' => array()
            ),
            $nrorg
        );

        if (!empty($result['messages'])) {
            throw new \Exception($result['messages'][0]['message']);
        }

        return $result['dataset']['getOcupacao'];
    }

    public function solicitaAlteracao($row) {
        try {
            $params = [
                'requestType'   => 'Row',
                'row'           => $row
            ];

            $result = $this->hcmServices->send('solicitaAlteracao', $params, $row['NRORG']);
            return $result;
		} catch (\Exception $e) {
			throw $e;
		}
    }

    public function getTipoRelacionamento(
        int $nrOrg
    ): array {
        $route = 'getTipoRelacionamento';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $tiposRel = $result['dataset'][$route];

        return $tiposRel;
    }

    public function getLinhaTransporteAtiva(
        int $nrOrg
    ): array {
        $route = 'getLinhaTransporteAtiva';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $linhas = $result['dataset'][$route];

        return $linhas;
    }

    public function getTipolinhavinc(
        int $nrOrg
    ): array {
        $route = 'getTipolinhavinc';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $tiposLinhas = $result['dataset'][$route];

        return $tiposLinhas;
    }

    public function getIntegtransp(
        int $nrOrg
    ): array {
        $route = 'getIntegtransp';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $numerosIntegracao = $result['dataset'][$route];

        return $numerosIntegracao;
    }

    public function getSentidolinha(
        int $nrOrg
    ): array {
        $route = 'getSentidolinha';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $sentidos = $result['dataset'][$route];

        return $sentidos;
    }

    public function getBeneficio(
        int $nrOrg
    ): array {
        $route = 'getBeneficio';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $beneficios = $result['dataset'][$route];

        return $beneficios;
    }

    public function getPessoaRelacionamentos(
        int $nrOrg,
        int $nrPessoa
    ): array {
        $route = 'getPessoaRelacionamentos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'NRPESSOA' => $nrPessoa,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $pessoas = $result['dataset'][$route];

        return $pessoas;
    }

    public function getTipoDependente(
        int $nrOrg
    ): array {
        $route = 'getTipoDependente';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $pessoas = $result['dataset'][$route];

        return $pessoas;
    }

    public function getParcnegocioVinculos(
        int $nrOrg
    ): array {
        $route = 'getParcnegocioVinculos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $parcs = $result['dataset'][$route];

        return $parcs;
    }

    public function getTipoprocessos(
        int $nrOrg
    ): array {
        $route = 'getTipoprocessos';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $tipos = $result['dataset'][$route];

        return $tipos;
    }

    public function getTemplate(
        int $nrOrg
    ): array {
        $route = 'getTemplate';

        $params = [
            'requestType' => 'Row',
            'row' => [
                'EMPTY' => null,
            ],
        ];

        $result = $this->hcmServices->send($route, $params, $nrOrg);
        $templates = $result['dataset'][$route];

        return $templates;
    }
}
